use yaml_rust::yaml;
use std::fs::File;
use std::str::FromStr;
use std::io::prelude::*;
use std::collections::HashMap;
pub mod server_conf;

static FILE: &str = "mrprox.conf";

pub struct Config{
    l_servers : HashMap<String, String>,
    file: Vec<yaml::Yaml>,
    port: String,
    port_conf: String,
}

impl Config {
    pub fn new() -> Self {
        let mut file = File::open(&FILE).unwrap();
        let mut s = String::new();
        file.read_to_string(&mut s).unwrap();
        let yam = yaml::YamlLoader::load_from_str(&s).unwrap();
        Self{
            l_servers: Self::get_servers(&yam),
            port: Self::get_port_f(&yam),
            port_conf: Self::get_conf_port_f(&yam),
            file: yam,
        }
    }

    fn get_port_f(file: &Vec<yaml::Yaml>) -> String {
        match file[0]["port"].as_str() {
            Some(h) => String::from(h),
            _ => String::from("25565"),
        }
    }

    fn get_conf_port_f(file: &Vec<yaml::Yaml>) -> String {
        match file[0]["port_conf"].as_str() {
            Some(h) => String::from(h),
            _ => String::from("25565"),
        }
    }

    fn get_servers(file: &Vec<yaml::Yaml>) -> HashMap<String, String> {
        let mut ret = HashMap::new();
        let docs2 = match file[0]["servers"] {
            yaml::Yaml::Hash(ref h) => h,
            _ => return ret,
        };


        for (k, v) in docs2{
            ret.insert(String::from(k.as_str().unwrap()),
                    String::from(v.as_str().unwrap()));
        }
        ret
    }

    fn get_host(&self, host: &String) -> Option<(&String, &String)>{
        self.l_servers.get_key_value(host)
    }

    pub fn get_server(&self, host: &String) -> Option<(String, u16)>{
        let raw: Vec<&str>;
        match self.get_host(host){
            Some(h) => raw=h.1.split(":").collect(),
            None => return None,
        }

        if raw.len() == 2 {

            match FromStr::from_str(raw[1]) {
                Ok(p) => return Some((String::from(raw[0]),p)),
                Err(_e) => return None,
            }
        } else {
            return None;
        }
    }

    pub fn get_port(&self) -> &String{
        &self.port
    }

    pub fn get_port_conf(&self) -> &String{
        &self.port_conf
    }
}
